exceptions.BaseException

Module exceptions :: Class BaseException |
[frames | no frames]

## Type BaseException

    object --+
             |
            BaseException

Known Subclasses:
  `Exception`

Common base class for all exceptions

Method Summary
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__getitem__`(x, y)` x.__getitem__(y) <==> x[y]
| ``__getslice__`(x, i, j)` Use of negative indices is not supported.
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| `__reduce__(...)`
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| `__setstate__(...)`
| ``__str__`(x)` x.__str__() <==> str(x)
Inherited from `object`: `__hash__`, `__reduce_ex__`

Class Variable Summary
`getset_descriptor` | `args` = `<attribute 'args' of 'exceptions.BaseException' o...`
`member_descriptor` | `message` = `<member 'message' of 'exceptions.BaseException...`

Method Details

### __init__(...) (Constructor) x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: `__builtin__.object.__init__`

### __delattr__(...) x.__delattr__('name') <==> del x.name Overrides: `__builtin__.object.__delattr__`

### __getattribute__(...) x.__getattribute__('name') <==> x.name Overrides: `__builtin__.object.__getattribute__`

    ### __getitem__(x, y) (Indexing operator) x.__getitem__(y) <==> x[y] Returns:
        x[y]

    ### __getslice__(x, i, j) (Slicling operator) Use of negative indices is not supported. Returns:
        x[i:j]

    ### __new__(T, S, ...) T.__new__(S, ...) -> a new object with type S, a subtype of T Returns:
        a new object with type S, a subtype of T
Overrides: `__builtin__.object.__new__`

    ### __repr__(x) (Representation operator) x.__repr__() <==> repr(x) Returns:
        repr(x)
Overrides: `__builtin__.object.__repr__`

### __setattr__(...) x.__setattr__('name', value) <==> x.name = value Overrides: `__builtin__.object.__setattr__`

    ### __str__(x) (Informal representation operator) x.__str__() <==> str(x) Returns:
        str(x)
Overrides: `__builtin__.object.__str__`

Class Variable Details

    ### args Type: `getset_descriptor` Value:
        <attribute 'args' of 'exceptions.BaseException' objects>

    ### message Type: `member_descriptor` Value:
        <member 'message' of 'exceptions.BaseException' objects>

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net